Retrieve the complete BAFU NAWA Trend parameter catalogue
Source:R/adapter_CH_BAFU_NAWA.R
bafu_nawa_parameters.RdThe catalogue includes all physicochemical parameters, nutrients,
micropollutants and the few hydrological parameters stored in NAWA. The
parameter column shows how each provider parameter is handled by
timeseries(). All entries classified as water_quality are returned
together when parameter = "water_quality" is requested.